pyxmpp2.streamtls

Package pyxmpp2 :: Module streamtls |
[hide private]

# Module streamtls

TLS support for XMPP streams.

Normative reference:
  - RFC 6120

Classes | [hide private]
| StreamTLSHandler Handler for stream TLS support.

Variables | [hide private]
| STARTTLS_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-tls}starttls``'``
| REQUIRED_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-tls}required``'``
| PROCEED_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-tls}proceed``'``
| FAILURE_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-tls}failure``'``
| logger = `logging.getLogger("pyxmpp.streamtls")`